Drivers - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# Hardware guide

## Core hardware

Drivers for these stations are included in the core WeeWX distribution. Each station type provides a different set of observations, at different sampling rates. These are enumerated in a Station data table in the page for each station.

AcuRite | TE923 | WMR100 | WS1
CC3000 | Ultimeter | WMR300 | WS23xx
FineOffset | Vantage | WMR9x8 | WS28xx

## Driver status

The following table enumerates many of the weather stations that are known to work with WeeWX. If your station is not in the table, check the pictures at the supported hardware page — it could be a variation of one of the supported models. You can also check the station comparison table — sometimes new models use the same communication protocols as older hardware.

The maturity column indicates the degree of confidence in the driver. For stations marked Tested, the station is routinely tested as part of the release process and should work as documented. For stations not marked at all, they are "known to work" using the indicated driver, but are not routinely tested. For stations marked Experimental, we are still working on the driver. There can be problems.

Weather hardware supported by WeeWX
Vendor | Model | Hardware Interface | Required Package | Driver | Maturity
AcuRite | 01025 | USB | pyusb | AcuRite12 |
01035 | USB | pyusb | AcuRite12 | Tested
01036 | USB | pyusb | AcuRite12 |
01525 | USB | pyusb | AcuRite12 |
02032 | USB | pyusb | AcuRite12 |
02064 | USB | pyusb | AcuRite12 |
06037 | USB | pyusb | AcuRite12 |
06039 | USB | pyusb | AcuRite12 |
Argent Data Systems | WS1 | Serial | pyusb | WS19 |
Aercus | WS2083 | USB | pyusb | FineOffsetUSB5 |
WS3083 | USB | pyusb | FineOffsetUSB5 |
Ambient Weather | WS1090 | USB | pyusb | FineOffsetUSB5 | Tested
WS2080 | USB | pyusb | FineOffsetUSB5 | Tested
WS2080A | USB | pyusb | FineOffsetUSB5 | Tested
WS2090 | USB | pyusb | FineOffsetUSB5 |
WS2095 | USB | pyusb | FineOffsetUSB5 |
Cresta | WRX815 | USB | pyusb | TE9238 |
PWS720 | USB | pyusb | TE9238 |
DAZA | DZ-WH1080 | USB | pyusb | FineOffsetUSB5 |
DZ-WS3101 | USB | pyusb | FineOffsetUSB5 |
DZ-WS3104 | USB | pyusb | FineOffsetUSB5 |
Davis | VantagePro2 | Serial or USB | pyserial | Vantage1 | Tested
VantagePro2 | WeatherLink IP |  | Vantage1 | Tested
VantageVue | Serial or USB | pyserial | Vantage1 | Tested
Elecsa | 6975 | USB | pyusb | FineOffsetUSB5 |
6976 | USB | pyusb | FineOffsetUSB5 |
Excelvan | Excelvan | USB | pyusb | FineOffsetUSB5 |
Fine Offset | WH1080 | USB | pyusb | FineOffsetUSB5 |
WH1081 | USB | pyusb | FineOffsetUSB5 |
WH1091 | USB | pyusb | FineOffsetUSB5 |
WH1090 | USB | pyusb | FineOffsetUSB5 |
WS1080 | USB | pyusb | FineOffsetUSB5 |
WA2080 | USB | pyusb | FineOffsetUSB5 |
WA2081 | USB | pyusb | FineOffsetUSB5 |
WH2080 | USB | pyusb | FineOffsetUSB5 |
WH2081 | USB | pyusb | FineOffsetUSB5 |
WH3080 | USB | pyusb | FineOffsetUSB5 |
WH3081 | USB | pyusb | FineOffsetUSB5 |
Froggit | WS8700 | USB | pyusb | TE9238 |
WH1080 | USB | pyusb | FineOffsetUSB5 |
WH3080 | USB | pyusb | FineOffsetUSB5 |
General Tools | WS831DL | USB | pyusb | TE9238 |
Hideki | DV928 | USB | pyusb | TE9238 |
TE821 | USB | pyusb | TE9238 |
TE827 | USB | pyusb | TE9238 |
TE831 | USB | pyusb | TE9238 |
TE838 | USB | pyusb | TE9238 |
TE923 | USB | pyusb | TE9238 |
Huger | WM918 | Serial | pyserial | WMR9x84 |
IROX | Pro X | USB | pyusb | TE9238 |
La Crosse | C86234 | USB | pyusb | WS28xx7 | Tested
WS-1640 | USB | pyusb | TE9238 |
WS-23XX | Serial | fcntl/select | WS23xx6 | Tested
WS-28XX | USB | pyusb | WS28xx7 |
Maplin | N96GY | USB | pyusb | FineOffsetUSB5 |
N96FY | USB | pyusb | FineOffsetUSB5 |
Meade | TE923W | USB | pyusb | TE9238 | Tested
TE923W-M | USB | pyusb | TE9238 |
TE924W | USB | pyusb | TE9238 |
Mebus | TE923 | USB | pyusb | TE9238 |
National Geographic | 265 | USB | pyusb | FineOffsetUSB5 |
Oregon Scientific | WMR88 | USB | pyusb | WMR1002 |
WMR88A | USB | pyusb | WMR1002 |
WMR100 | USB | pyusb | WMR1002 |
WMR100N | USB | pyusb | WMR1002 | Tested
WMR180 | USB | pyusb | WMR1002 |
WMR180A | USB | pyusb | WMR1002 |
WMRS200 | USB | pyusb | WMR1002 |
WMR300 | USB | pyusb | WMR3003 | Experimental
WMR300A | USB | pyusb | WMR3003 | Experimental
WMR918 | Serial | pyserial | WMR9x84 |
WMR928N | Serial | pyserial | WMR9x84 | Tested
WMR968 | Serial | pyserial | WMR9x84 | Tested
PeetBros | Ultimeter 100 | Serial | pyserial | Ultimeter10 |
Ultimeter 800 | Serial | pyserial | Ultimeter10 |
Ultimeter 2000 | Serial | pyserial | Ultimeter10 |
Ultimeter 2100 | Serial | pyserial | Ultimeter10 |
RainWise | Mark III | Serial | pyserial | CC300011 |
CC3000 | Serial | pyserial | CC300011 | Tested
Radio Shack | 63-256 | USB | pyusb | WMR1002 |
63-1016 | Serial | pyserial | WMR9x84 |
Sinometer | WS1080 / WS1081 | USB | pyusb | FineOffsetUSB5 |
WS3100 / WS3101 | USB | pyusb | FineOffsetUSB5 |
TechnoLine | WS-2300 | Serial | fcntl/select | WS23xx6 |
WS-2350 | Serial | fcntl/select | WS23xx6 |
TFA | Matrix | Serial | fcntl/select | WS23xx6 |
Nexus | USB | pyusb | TE9238 |
Opus | USB | pyusb | WS28xx7 |
Primus | USB | pyusb | WS28xx7 |
Sinus | USB | pyusb | TE9238 |
Tycon | TP1080WC | USB | pyusb | FineOffsetUSB5 |
Watson | W-8681 | USB | pyusb | FineOffsetUSB5 |
WX-2008 | USB | pyusb | FineOffsetUSB5 |
Velleman | WS3080 | USB | pyusb | FineOffsetUSB5 |
Ventus | W831 | USB | pyusb | TE9238 |
W928 | USB | pyusb | TE9238 |

Davis "Vantage" series of weather stations, including the VantagePro2™ and VantageVue™, using serial, USB, or WeatherLinkIP™ connections. Both the "Rev A" (firmware dated before 22 April 2002) and "Rev B" versions are supported.

Oregon Scientific WMR-100 stations. Tested on the Oregon Scientific WMR100N.

Oregon Scientific WMR-300 stations. Tested on the Oregon Scientific WMR300A.

Oregon Scientific WMR-9x8 stations. Tested on the Oregon Scientific WMR968.

Fine Offset 10xx, 20xx, and 30xx stations. Tested on the Ambient Weather WS2080.

La Crosse WS-23xx stations. Tested on the La Crosse 2317.

La Crosse WS-28xx stations. Tested on the La Crosse C86234.

Hideki Professional Weather Stations. Tested on the Meade TE923.

ADS WS1 Stations. Tested on the WS1.

PeetBros Ultimeter Stations. Tested on the Ultimeter 2000.

RainWise Mark III Stations. Tested on the CC3000 (firmware "Rainwise CC-3000 Version: 1.3 Build 022 Dec 02 2016").

AcuRite Weather Stations. Tested on the 01036RX.